@@ -70,8 +70,7 @@ test_that("timeunit works correctly", {
   )
 
   # check that minTimeunit finds the smallest timeunit of the modules loaded
-  whNotNA <- sapply(depends(mySim)@dependencies,
-                    function(x) !is.na(x@timeunit))
+  whNotNA <- sapply(depends(mySim)@dependencies, function(x) !is.na(x@timeunit))
   expect_equivalent(as.numeric(eval(parse(
     text = paste0("d", minTimeunit(mySim), "(1)")))),
     min(sapply(depends(mySim)@dependencies[whNotNA],
@@ -106,6 +105,8 @@ test_that("timeunit works correctly", {
 })
 
 test_that("timeunits with child and parent modules work correctly", {
+  skip_on_cran()
+
   m <- testInit("igraph", smcc = TRUE)
   options("spades.memoryUseInterval" = 0)
   on.exit({
@@ -201,8 +202,8 @@ test_that("timeunits with child and parent modules work correctly", {
             "  cm1 <- currentModule(sim)", "  dp1 <- dataPath(sim)")
   cat(xxx1, file = fileName, sep = "\n")
   mySim <- simInit(modules = list(modName), paths = list(modulePath = tmpdir))
-  expect_true(mySim[[modName]]$cm1 == file.path(modName))
-  expect_true(mySim[[modName]]$dp1 == normPath(file.path(dirname(fileName), "data")))
+  expect_true(mySim@.xData$.mods[[modName]]$cm1 == file.path(modName))
+  expect_true(mySim@.xData$.mods[[modName]]$dp1 == normPath(file.path(dirname(fileName), "data")))
 
   mySimOut <- spades(mySim)
   expect_true(mySimOut$cm == file.path(modName))
@@ -235,7 +236,6 @@ test_that("timeunits with child and parent modules work correctly", {
                      params = list("child6" = list(.useCache = ".inputObjects")))
   })
 
-
   xxx1 <- c(xxx[seq(lineOfInterest1 - 1)], "  expectsInput(\"b\", \"character\", \"temp thing\"),",
             xxx[seq(length(xxx) - lineOfInterest1) + lineOfInterest1])
   cat(xxx1, file = fileName, sep = "\n")
